@@ -7,7 +7,7 @@ use std::{
     fs::{self, create_dir_all, read_to_string, OpenOptions},
     io::{self, Write},
     mem::take,
-    path::{Path, PathBuf},
+    path::Path,
     process::Command,
     rc::Rc,
     sync::{Arc, RwLock},
